@@ -1,6 +1,6 @@
 package Map::Tube::CLI;
 
-$Map::Tube::CLI::VERSION   = '0.33';
+$Map::Tube::CLI::VERSION   = '0.34';
 $Map::Tube::CLI::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::CLI - Command Line Interface for Map::Tube::* map.
 
 =head1 VERSION
 
-Version 0.33
+Version 0.34
 
 =cut
 
@@ -29,7 +29,7 @@ use Module::Pluggable
     max_depth   => 3;
 
 use Moo;
-use namespace::clean;
+use namespace::autoclean;
 use MooX::Options;
 with 'Map::Tube::CLI::Option';
 
